<template>
  <view-grid ref="grid" :columns="columns" :detail="detail" :editFormFields="editFormFields"
    :editFormOptions="editFormOptions" :searchFormFields="searchFormFields" :searchFormOptions="searchFormOptions"
    :table="table" :extend="extend">
  </view-grid>
</template>
<script>
import extend from "@/extension/inbound/mesProInOrderDetail.js";
import { ref, defineComponent } from "vue";
export default defineComponent({
  setup() {
    const table = ref({
      key: "id",
      footer: "Foots",
      cnName: "成品入库明细信息",
      name: "mesProInOrderDetail",
      url: "/mesProInOrderDetail/",
      sortName: "id",
    });
    const editFormFields = ref({
      deviceCode: "",
      deviceName: "",
      deviceType: "",
      deviceStatus: "",
      deviceIp: "",
      devicePort: "",
      devicePlcType: "",
      deviceRemark: "",
    });
    const editFormOptions = ref([
      [
        {
          title: "物料编号",
          required: true,
          field: "materielCode",
          type: "string",
        },
        {
          title: "单据编号",
          required: true,
          field: "materielName",
          type: "string",
        },
        {
          title: "批次号",
          required: true,
          field: "orderNo",
          type: "string",
        },
        {
          title: "序列号",
          required: true,
          field: "serialNumber",
          type: "string",
        },
      ],
      
    ]);
    const searchFormFields = ref({
      materielCode: "",
      materielName: "",
      orderNo: "",
    });
    const searchFormOptions = ref([
      [
        { title: "物料编号", field: "materielCode" },
        { title: "物料名称", field: "materielName" },
        { title: "单据编号", field: "orderNo" },
      ],
    ]);
    const columns = ref([
      {
        field: "id",
        title: "Id",
        type: "int",
        width: 90,
        hidden: true,
        readonly: true,
        require: true,
        align: "left",
      },
      {
        field: "orderId",
        title: "入库单主键",
        type: "string",
        width: 90,
        align: "left",
      },
      {
        field: "bagNo",
        title: "内包号",
        type: "string",
        width: 150,
        align: "left",
      },
      {
        field: "productCode",
        title: "产品编码",
        type: "string",
        width: 150,
        align: "left",
      },
    {
        field: "overInQuantity",
        title: "上架数量",
        type: "string",
        width: 180,
        align: "left",
      },
      {
        field: "productVersion",
        title: "版本",
        type: "string",
        width: 90,
        align: "left",
      },
      {
        field: "setQty",
        title: "包装SET数量",
        type: "string",
        width: 120,
        align: "left",
      },
      {
        field: "okpcsqty",
        title: "合格PCS数",
        type: "string",
        width: 200,
        align: "left",
      },
       {
        field: "dateCode",
        title: "周期",
        type: "string",
        width: 200,
        align: "left",
      },
       {
        field: "xQty",
        title: "X数",
        type: "string",
        width: 200,
        align: "left",
      },
       {
        field: "xSite",
        title: "X位",
        type: "string",
        width: 200,
        align: "left",
      },
       {
        field: "weight",
        title: "内包重量",
        type: "string",
        width: 200,
        align: "left",
      },
       {
        field: "packingDate",
        title: "包装时间",
        type: "datetime",
        width: 200,
        align: "left",
      },
       {
        field: "lotNumber",
        title: "批次号",
        type: "string",
        width: 200,
        align: "left",
      },
       {
        field: "erpOrder",
        title: "ERP工单",
        type: "string",
        width: 200,
        align: "left",
      },
       {
        field: "moNumber",
        title: "制造订单",
        type: "string",
        width: 200,
        align: "left",
      },
       {
        field: "saleOrder",
        title: "销售订单",
        type: "string",
        width: 200,
        align: "left",
      }, {
        field: "remark",
        title: "备注",
        type: "string",
        width: 200,
        align: "left",
      },
      {
        field: "creater",
        title: "创建人",
        type: "string",
        width: 90,
        align: "left",
      },
      {
        field: "createDate",
        title: "创建时间",
        type: "datetime",
        width: 160,
        align: "left",
      },
      {
        field: "modifier",
        title: "修改人",
        type: "string",
        width: 100,
        align: "left",
      },
      {
        field: "modifyDate",
        title: "修改时间",
        type: "datetime",
        width: 160,
        align: "left",
      },
      {
        field: "remark",
        title: "备注",
        type: "string",
        width: 100,
        align: "left",
      },
    ]);
    const detail = ref({
      cnName: "#detailCnName",
      table: "",
      columns: [],
      sortName: "",
    });
    return {
      table,
      extend,
      editFormFields,
      editFormOptions,
      searchFormFields,
      searchFormOptions,
      columns,
      detail,
    };
  },
});
</script>